/*
 * jabberd - Jabber Open Source Server
 * Copyright (c) 2002 Jeremie Miller, Thomas Muldowney,
 *                    Ryan Eatmon, Robert Norris
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA02111-1307USA
 */

#ifndef INCL_MIO_INADDR_H
#define INCL_MIO_INADDR_H

#include "mio.h"

#ifdef __cplusplus
extern "C" {
#endif   

/**
 * @file mio_inaddr.h
 * @brief object like wrapper around sockaddr_storage
 *
 * The functions defined in this header file are used to access the
 * struct sockaddr_storage. This structure is seen as an object that
 * contains an IPv4 or an IPv6 address and these methods are the
 * access methods.
 */

/* wrappers to access sockaddr_storage structures */
int _mio_inet_pton(char *src, struct sockaddr_storage *dst);
const char *_mio_inet_ntop(struct sockaddr_storage *src, char *dst, size_t size);
int _mio_inet_getport(struct sockaddr_storage *sa);
int _mio_inet_setport(struct sockaddr_storage *sa, in_port_t port);
uint8_t _mio_addrlen(struct sockaddr_storage *sa);

#ifdef __cplusplus
}
#endif

#endif  /* INCL_MIO_INADDR_H */

